# TYPE INTO PYTHON CONSOLE FIRST:
#
# import movieHelper
# 
# NOW USE FUNCTION AS (for example):
#
# movieHelper.rotateAboutOrigin(10)

import time
import math
import GenGisAPIv1 as ggAPI

def rotateAboutOrigin(degree, timeForRotation):
	"""
	Rotate camera about the origin.

	@param degree: number of degrees to rotate
	@param timeForRotation: time to perform complete rotation (in seconds)
	"""

	secPerDeg = timeForRotation / float(degree)
	sleepTime = float(secPerDeg) / 3
	for i in xrange(0,int(degree)):
		ggAPI.rotate(0.33333)
		ggAPI.refresh()
		time.sleep(sleepTime)
		ggAPI.rotate(0.33333)
		ggAPI.refresh()
		time.sleep(sleepTime)
		ggAPI.rotate(0.33333)
		ggAPI.refresh()
		time.sleep(sleepTime)
		ggAPI.wxSafeYield()
		
def getCameraParam():
	"""
	Get current camera parameters.

	@return: list with camera parameters (position, yaw, pitch)
	"""
	return [ggAPI.getPosition(), ggAPI.getYaw(), ggAPI.getPitch()]
	
def setCameraParam(cameraParam):
	"""
	Set camera parameters.
	"""
	ggAPI.setPosition(cameraParam[0].x, cameraParam[0].y, cameraParam[0].z)
	ggAPI.setYaw(cameraParam[1])
	ggAPI.setPitch(cameraParam[2])
	ggAPI.refresh()
	
def linearInterpolateParams(param1, param2, time):
	"""
	Linearly interpolate the camera between two parameter sets.

	@param param1: starting parameters of camera
	@param param2: end parameters of camera
	@param time: time for camera to move from starting to end parameters
	"""
	linearInterpolate(param1[0], param1[1], param1[2], param2[0], param2[1], param2[2], time)
		
def linearInterpolate(pos1, yaw1, pitch1, pos2, yaw2, pitch2, timeInterp):
	"""
	Linearly interpolate the camera between two parameter sets.

	@param pos1: starting position of camera
	@param yaw1: starting yaw angle of camera
	@param pitch1: starting pitch angle of camera
	@param pos2: end position of camera
	@param yaw2: end yaw angle of camera
	@param pitch2: end pitch angle of camera
	@param timeInterp: time for camera to move from starting to end parameters
	"""
	
	# amount to change each parameter by
	dx = pos2.x - pos1.x
	dy = pos2.y - pos1.y
	dz = pos2.z - pos1.z
	dYaw = yaw2 - yaw1
	if(dYaw > 180 or dYaw < -180):
		dYaw = (180 - dYaw)
	dPitch = pitch2 - pitch1
	
	# amount to change each paramter by each 1/20 second
	dx = float(dx) / (20*timeInterp)
	dy = float(dy) / (20*timeInterp)
	dz = float(dz) / (20*timeInterp)
	dYaw = float(dYaw) / (20*timeInterp)
	dPitch = float(dPitch) / (20*timeInterp)
	
	# perform linear interpolation
	steps = math.floor(int(20*timeInterp))
	for i in xrange(0, int(steps+1)):
		ggAPI.setPosition(pos1.x + i*dx, pos1.y + i*dy, pos1.z + i*dz)
		ggAPI.setYaw(yaw1 + i*dYaw)
		ggAPI.setPitch(pitch1 + i*dPitch)
		ggAPI.refresh()
		ggAPI.wxSafeYield()
		time.sleep(0.05)
	
	# make sure camera ends in exact position specified
	ggAPI.setPosition(pos2.x, pos2.y, pos2.z)
	ggAPI.setYaw(yaw2)
	ggAPI.setPitch(pitch2)